@@ -7,14 +7,14 @@ test_that('Statistics obey antisymmetry property', {
   G = cbind(X, Xk)
   y = prob$y
     
-  i = sort(sample(p, sample(p))) # Indices to swap.
+  i = sort(sample(p, sample(p,1))) # Indices to swap.
   G_swap = G
   G_swap[,c(i,i+p)] <- G[,c(i+p,i)]
   
   expect_antisymmetric <- function(stat) {
     orig = 1:p; ko = (p+1):(2*p);
-    expect_equal(stat(G[,orig],G[,ko],y), 
-                 stat(G_swap[,orig],G_swap[,ko],y) * ifelse(1:p %in% i, -1, 1),tolerance = 1e-3)
+    expect_equal(stat(G[,orig],G[,ko],y),
+                 stat(G_swap[,orig],G_swap[,ko],y) * ifelse(1:p %in% i, -1, 1), tolerance = 1e-3)
   }
   expect_antisymmetric(stat.forward_selection)
   stats_fs_omp = function(X,Xk,y) stat.forward_selection(X, Xk, y, omp=FALSE)
@@ -34,4 +34,4 @@ test_that('Finding the max lambda in lasso works for orthonormal design', {
   beta_ls = as.vector(t(X) %*% y)
   expect_equal(lasso_max_lambda_glmnet(X, y, nlambda = 1e4, intercept=F, standardize=F), abs(beta_ls),
                tolerance = 1e-3)
-})
\ No newline at end of file
+})
